@@ -56,9 +56,15 @@ class Song:
         return Track(song=self, proto=self._proto.tracks[index])
 
     def serialize(self):
-        # type: ignore
         return b64encode(self._proto.SerializeToString()).decode('ascii')
 
+    def serialize_to_bytestring(self) -> str:
+        '''
+        Note here the returned string is essentially bytes, just using the str form for convenience.
+        See https://protobuf.dev/getting-started/pythontutorial/#parsing-serialization
+        '''
+        return self._proto.SerializeToString()
+
     @staticmethod
     def deserialize(serialized_song_string: str):
         song_proto = song_pb2.Song()
@@ -66,6 +72,15 @@ class Song:
             b64decode(serialized_song_string))  # type: ignore
         return Song(proto=song_proto)
 
+    @staticmethod
+    def deserialize_from_bytestring(serialized_song_bytestring: str):
+        '''
+        Note here the input string is essentially bytes, generated by `serialize_to_bytestring` or equivalent method in other languages.
+        '''
+        song_proto = song_pb2.Song()
+        song_proto.ParseFromString(serialized_song_bytestring)
+        return Song(proto=song_proto)
+
     @staticmethod
     def from_midi(midi_obj: MidiFile):
         '''
